@@ -214,7 +214,8 @@ func transformPodSpec(metadata *metav1.ObjectMeta, podSpec *v1.PodSpec, retrieve
 	// the set of image IDs required to provide debugging support files
 	requiredSupportImages := make(map[string]bool)
 	for i := range podSpec.Containers {
-		container := &podSpec.Containers[i]
+		container := podSpec.Containers[i] // make a copy and only apply changes on successful transform
+
 		// the usual retriever returns an error for non-build artifacts
 		imageConfig, err := retrieveImageConfiguration(container.Image)
 		if err != nil {
@@ -222,18 +223,18 @@ func transformPodSpec(metadata *metav1.ObjectMeta, podSpec *v1.PodSpec, retrieve
 		}
 		// requiredImage, if not empty, is the image ID providing the debugging support files
 		// `err != nil` means that the container did not or could not be transformed
-		if configuration, requiredImage, err := transformContainer(container, imageConfig, portAlloc); err == nil {
+		if configuration, requiredImage, err := transformContainer(&container, imageConfig, portAlloc); err == nil {
 			configuration.Artifact = imageConfig.artifact
 			if configuration.WorkingDir == "" {
 				configuration.WorkingDir = imageConfig.workingDir
 			}
 			configurations[container.Name] = configuration
+			podSpec.Containers[i] = container // apply any configuration changes
 			if len(requiredImage) > 0 {
 				logrus.Infof("%q requires debugging support image %q", container.Name, requiredImage)
-				containersRequiringSupport = append(containersRequiringSupport, container)
+				containersRequiringSupport = append(containersRequiringSupport, &podSpec.Containers[i])
 				requiredSupportImages[requiredImage] = true
 			}
-			// todo: add this artifact to the watch list?
 		} else {
 			logrus.Warnf("Image %q not configured for debugging: %v", container.Name, err)
 		}
@@ -332,7 +333,7 @@ func transformContainer(container *v1.Container, config imageConfiguration, port
 	next := func(container *v1.Container, config imageConfiguration) (ContainerDebugConfiguration, string, error) {
 		return performContainerTransform(container, config, portAlloc)
 	}
-	if _, found := config.labels["io.buildpacks.stack.id"]; found && len(config.entrypoint) > 0 && config.entrypoint[0] == "/cnb/lifecycle/launcher" {
+	if isCNBImage(config) {
 		return updateForCNBImage(container, config, next)
 	}
 	return updateForShDashC(container, config, next)
@@ -387,6 +388,7 @@ func isShDashC(cmd, arg string) bool {
 }
 
 func performContainerTransform(container *v1.Container, config imageConfiguration, portAlloc portAllocator) (ContainerDebugConfiguration, string, error) {
+	logrus.Tracef("Examining container %q with config %v", container.Name, config)
 	for _, transform := range containerTransforms {
 		if transform.IsApplicable(config) {
 			return transform.Apply(container, config, portAlloc)
