@@ -30,6 +30,62 @@ import (
 	"github.com/GoogleContainerTools/skaffold/testutil"
 )
 
+func TestTest(t *testing.T) {
+	tests := []struct {
+		description     string
+		testBench       *TestBench
+		cfg             []*latest.Artifact
+		artifacts       []build.Artifact
+		expectedActions []Actions
+		shouldErr       bool
+	}{
+		{
+			description: "test no error",
+			testBench:   &TestBench{},
+			cfg:         []*latest.Artifact{{ImageName: "img1"}, {ImageName: "img2"}},
+			artifacts: []build.Artifact{
+				{ImageName: "img1", Tag: "img1:tag1"},
+				{ImageName: "img2", Tag: "img2:tag2"},
+			},
+			expectedActions: []Actions{{
+				Tested: []string{"img1:tag1", "img2:tag2"},
+			}},
+		},
+		{
+			description:     "no artifacts",
+			testBench:       &TestBench{},
+			artifacts:       []build.Artifact(nil),
+			expectedActions: []Actions{{}},
+		},
+		{
+			description: "missing tag",
+			testBench:   &TestBench{},
+			cfg:         []*latest.Artifact{{ImageName: "image1"}},
+			artifacts:   []build.Artifact{{ImageName: "image1"}},
+			expectedActions: []Actions{{
+				Tested: []string{""},
+			}},
+		},
+		{
+			description:     "test error",
+			testBench:       &TestBench{testErrors: []error{errors.New("")}},
+			expectedActions: []Actions{{}},
+			shouldErr:       true,
+		},
+	}
+	for _, test := range tests {
+		testutil.Run(t, test.description, func(t *testutil.T) {
+			runner := createRunner(t, test.testBench, nil, test.cfg)
+
+			err := runner.Test(context.Background(), ioutil.Discard, test.artifacts)
+
+			t.CheckError(test.shouldErr, err)
+
+			t.CheckErrorAndDeepEqual(test.shouldErr, err, test.expectedActions, test.testBench.Actions())
+		})
+	}
+}
+
 func TestBuildTestDeploy(t *testing.T) {
 	tests := []struct {
 		description     string
@@ -80,10 +136,13 @@ func TestBuildTestDeploy(t *testing.T) {
 				ImageName: "img",
 			}}
 
-			runner := createRunner(t, test.testBench, nil)
-			bRes, err := runner.BuildAndTest(ctx, ioutil.Discard, artifacts)
+			runner := createRunner(t, test.testBench, nil, artifacts)
+			bRes, err := runner.Build(ctx, ioutil.Discard, artifacts)
 			if err == nil {
-				err = runner.DeployAndLog(ctx, ioutil.Discard, bRes)
+				err = runner.Test(ctx, ioutil.Discard, bRes)
+				if err == nil {
+					err = runner.DeployAndLog(ctx, ioutil.Discard, bRes)
+				}
 			}
 
 			t.CheckErrorAndDeepEqual(test.shouldErr, err, test.expectedActions, test.testBench.Actions())
@@ -91,16 +150,17 @@ func TestBuildTestDeploy(t *testing.T) {
 	}
 }
 
-func TestBuildAndTestDryRun(t *testing.T) {
+func TestBuildDryRun(t *testing.T) {
 	testutil.Run(t, "", func(t *testutil.T) {
 		testBench := &TestBench{}
-		runner := createRunner(t, testBench, nil)
-		runner.runCtx.Opts.DryRun = true
-
-		bRes, err := runner.BuildAndTest(context.Background(), ioutil.Discard, []*latest.Artifact{
+		artifacts := []*latest.Artifact{
 			{ImageName: "img1"},
 			{ImageName: "img2"},
-		})
+		}
+		runner := createRunner(t, testBench, nil, artifacts)
+		runner.runCtx.Opts.DryRun = true
+
+		bRes, err := runner.Build(context.Background(), ioutil.Discard, artifacts)
 
 		t.CheckNoError(err)
 		t.CheckDeepEqual([]build.Artifact{
@@ -111,16 +171,17 @@ func TestBuildAndTestDryRun(t *testing.T) {
 	})
 }
 
-func TestBuildAndTestSkipBuild(t *testing.T) {
+func TestBuildSkipBuild(t *testing.T) {
 	testutil.Run(t, "", func(t *testutil.T) {
 		testBench := &TestBench{}
-		runner := createRunner(t, testBench, nil)
-		runner.runCtx.Opts.DigestSource = "none"
-
-		bRes, err := runner.BuildAndTest(context.Background(), ioutil.Discard, []*latest.Artifact{
+		artifacts := []*latest.Artifact{
 			{ImageName: "img1"},
 			{ImageName: "img2"},
-		})
+		}
+		runner := createRunner(t, testBench, nil, artifacts)
+		runner.runCtx.Opts.DigestSource = "none"
+
+		bRes, err := runner.Build(context.Background(), ioutil.Discard, artifacts)
 
 		t.CheckNoError(err)
 		t.CheckDeepEqual([]build.Artifact{}, bRes)
