@@ -29,6 +29,7 @@ import (
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/deploy"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/latest"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/test"
+	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/util"
 )
 
 // WithTimings creates a deployer that logs the duration of each phase.
@@ -60,8 +61,7 @@ func (w withTimings) Build(ctx context.Context, out io.Writer, tags tag.ImageTag
 	if err != nil {
 		return nil, err
 	}
-
-	logrus.Infoln("Build complete in", time.Since(start))
+	logrus.Infoln("Build completed in", util.ShowHumanizeTime(time.Since(start)))
 	return bRes, nil
 }
 
@@ -72,8 +72,7 @@ func (w withTimings) Test(ctx context.Context, out io.Writer, builds []build.Art
 	if err != nil {
 		return err
 	}
-
-	logrus.Infoln("Test complete in", time.Since(start))
+	logrus.Infoln("Test completed in", util.ShowHumanizeTime(time.Since(start)))
 	return nil
 }
 
@@ -85,8 +84,7 @@ func (w withTimings) Deploy(ctx context.Context, out io.Writer, builds []build.A
 	if err != nil {
 		return nil, err
 	}
-
-	logrus.Infoln("Deploy complete in", time.Since(start))
+	logrus.Infoln("Deploy completed in", util.ShowHumanizeTime(time.Since(start)))
 	return ns, err
 }
 
@@ -98,8 +96,7 @@ func (w withTimings) Cleanup(ctx context.Context, out io.Writer) error {
 	if err != nil {
 		return err
 	}
-
-	logrus.Infoln("Cleanup complete in", time.Since(start))
+	logrus.Infoln("Cleanup completed in", util.ShowHumanizeTime(time.Since(start)))
 	return nil
 }
 
@@ -111,7 +108,6 @@ func (w withTimings) Prune(ctx context.Context, out io.Writer) error {
 	if err != nil {
 		return err
 	}
-
-	logrus.Infoln("Image prune complete in", time.Since(start))
+	logrus.Infoln("Image prune completed in", util.ShowHumanizeTime(time.Since(start)))
 	return nil
 }
